@@ -14,7 +14,7 @@ from logging.handlers import TimedRotatingFileHandler
 
 from dbus.mainloop.glib import DBusGMainLoop
 DBusGMainLoop(set_as_default=True)
-from gi.repository.GLib import MainLoop
+from gi.repository.GLib import MainLoop  # noqa
 
 from comitup import cdns         # noqa
 from comitup import config       # noqa
@@ -53,7 +53,7 @@ def load_data():
     conf = config.Config(
                 CONF_PATH,
                 defaults={
-                    'ap_name': 'comitup-<nn>',
+                    'ap_name': 'comitup-<nnn>',
                     'ap_password': '',
                     'web_service': '',
                     'external_callback': '/usr/local/bin/comitup-callback',
